@@ -91,7 +91,11 @@ public:
         AllowRunningInsecureContent,
         AllowGeolocationOnInsecureOrigins,
         AllowWindowActivationFromJavaScript,
-        ShowScrollBars
+        ShowScrollBars,
+        PlaybackRequiresUserGesture,
+        WebRTCPublicInterfacesOnly,
+        JavascriptCanPaste,
+        DnsPrefetchEnabled,
     };
 
     enum FontSize {
@@ -101,6 +105,12 @@ public:
         DefaultFixedFontSize
     };
 
+    enum UnknownUrlSchemePolicy {
+        DisallowUnknownUrlSchemes = 1,
+        AllowUnknownUrlSchemesFromUserInteraction,
+        AllowAllUnknownUrlSchemes
+    };
+
 #if QT_DEPRECATED_SINCE(5, 5)
     static QWebEngineSettings *globalSettings();
 #endif
@@ -121,6 +131,10 @@ public:
     void setDefaultTextEncoding(const QString &encoding);
     QString defaultTextEncoding() const;
 
+    UnknownUrlSchemePolicy unknownUrlSchemePolicy() const;
+    void setUnknownUrlSchemePolicy(UnknownUrlSchemePolicy policy);
+    void resetUnknownUrlSchemePolicy();
+
 private:
     Q_DISABLE_COPY(QWebEngineSettings)
     typedef ::QtWebEngineCore::WebEngineSettings QWebEngineSettingsPrivate;
